@@ -3,11 +3,11 @@
 
 /* .C calls */
 extern void doproj(void *, void *, void *, void *, void *);
-extern void setproj(void *, void *, void *, void *, void *);
+extern void setproj(void *, void *, void *, void *);
 
 static const R_CMethodDef CEntries[] = {
     {"doproj",  (DL_FUNC) &doproj,  5},
-    {"setproj", (DL_FUNC) &setproj, 5},
+    {"setproj", (DL_FUNC) &setproj, 4},
     {NULL, NULL, 0}
 };
 
