@@ -16,14 +16,14 @@ Xperspective(struct place *place, double *x, double *y)
 	*y = - r*place->wlon.c;
 	if(r>4.)
 		return(-1);
-	if(fabs(viewpt)>1 && place->nlat.s<1/viewpt ||
-	   fabs(viewpt)<=1 && place->nlat.s<viewpt)
+	if( ((fabs(viewpt) > 1 ) && (place->nlat.s < 1/viewpt)) ||
+	    ((fabs(viewpt) <= 1) && (place->nlat.s < viewpt))   )
 			return 0;
 	return(1);
 }
 
 proj
-map_perspective(double radius) /* RSB */
+map_perspective(double radius, double dummy) /* RSB */
 {
 	viewpt = radius;
 	if(viewpt >= ORTHRAD)
@@ -47,14 +47,14 @@ Xstereographic(struct place *place, double *x, double *y)
 }
 
 proj
-stereographic(void)
+stereographic(double dummy1, double dummy2)
 {
 	viewpt = -1.;
 	return(Xperspective);
 }
 
 proj
-gnomonic(void)
+gnomonic(double dummy1, double dummy2)
 {
 	viewpt = 0.;
 	return(Xperspective);
